@@ -1,21 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2005 by Carsten Niehaus <cniehaus@kde.org>              *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2005 Carsten Niehaus <cniehaus@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef CHEMICALDATAOBJECT_H
 #define CHEMICALDATAOBJECT_H
@@ -74,12 +61,70 @@ public:
         halfLife/**< The halflife */,
         alphaDecayLikeliness/**< The percentage of alphadecay */,
         alphaDecay/**< The decayenergy of alphadecay in MeV */,
+        alphabetaminusDecayLikeliness/**< The percentage of alphadecay */,
+        alphabetaminusDecay/**< The decayenergy of alphadecay in MeV */,
         betaplusDecayLikeliness/**< The percentage of betaplusdecay */,
         betaplusDecay/**< The decayenergy of betaplusdecay in MeV */,
+        twobetaplusDecayLikeliness,
+        twobetaplusDecay,
+        betaplusprotonDecayLikeliness/**< The percentage of betaplusdecay */,
+        betaplusprotonDecay/**< The decayenergy of betaplusdecay in MeV */,
+        betaplustwoprotonDecayLikeliness,
+        betaplustwoprotonDecay,
+        betaplusalphaDecayLikeliness/**< The percentage of betaplusdecay */,
+        betaplusalphaDecay/**< The decayenergy of betaplusdecay in MeV */,
+        betaplustwoalphaDecayLikeliness,
+        betaplustwoalphaDecay,
+        betaplusthreealphaDecayLikeliness,
+        betaplusthreealphaDecay,
         betaminusDecayLikeliness/**< The percentage of betaminusdecay */,
         betaminusDecay/**< The decayenergy of betaminusdecay in MeV */,
+        twobetaminusDecayLikeliness,
+        twobetaminusDecay,
+        betaminusneutronDecayLikeliness/**< The percentage of betaminusdecay */,
+        betaminusneutronDecay/**< The decayenergy of betaminusdecay in MeV */,
+        betaminustwoneutronDecayLikeliness,
+        betaminustwoneutronDecay,
+        betaminusthreeneutronDecayLikeliness,
+        betaminusthreeneutronDecay,
+        betaminusfourneutronDecayLikeliness,
+        betaminusfourneutronDecay,
+        betaminusfissionDecayLikeliness/**< The percentage of betaminusdecay */,
+        betaminusfissionDecay/**< The decayenergy of betaminusdecay in MeV */,
+        betaminusalphaDecayLikeliness/**< The percentage of betaminusdecay */,
+        betaminusalphaDecay/**< The decayenergy of betaminusdecay in MeV */,
+        betaminustwoalphaDecayLikeliness,
+        betaminustwoalphaDecay,
+        betaminusthreealphaDecayLikeliness,
+        betaminusthreealphaDecay,
+        betaminusalphaneutronDecay,
+        betaminusalphaneutronDecayLikeliness,
         ecDecayLikeliness/**< The percentage of ecdecay */,
         ecDecay/**< The decayenergy of ecminusdecay in MeV */,
+        twoecDecayLikeliness,
+        twoecDecay,
+        ecalphaDecayLikeliness,
+        ecalphaDecay,
+        ecalphaprotonDecayLikeliness,
+        ecalphaprotonDecay,
+        ecprotonDecayLikeliness,
+        ecprotonDecay,
+        ectwoprotonDecayLikeliness,
+        ectwoprotonDecay,
+        ecthreeprotonDecayLikeliness,
+        ecthreeprotonDecay,
+        protonDecayLikeliness/**< The percentage of protondecay */,
+        protonDecay/**< The decayenergy of protonminusdecay in MeV */,
+        twoprotonDecayLikeliness,
+        twoprotonDecay,
+        protonalphaDecayLikeliness/**< The percentage of protondecay */,
+        protonalphaDecay/**< The decayenergy of protonminusdecay in MeV */,
+        neutronDecayLikeliness/**< The percentage of neutrondecay */,
+        neutronDecay/**< The decayenergy of neutronminusdecay in MeV */,
+        twoneutronDecayLikeliness,
+        twoneutronDecay,
+        spontfissionDecayLikeliness,
+        spontfissionDecay,
         dangerSymbol/**< the danger symbols are the dangers associated with an element, for example Xn,T+ */,
         RPhrase/**< */,
         SPhrase/**< */,
