@@ -1,16 +1,8 @@
-/***************************************************************************
-    copyright            : (C) 2006 by Carsten Niehaus <cniehaus@kde.org>
-                           (C) 2007 by Ian Monroe <ian@monroe.nu>
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2006 Carsten Niehaus <cniehaus@kde.org>
+    SPDX-FileCopyrightText: 2007 Ian Monroe <ian@monroe.nu>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "tablesdialog.h"
 
